@@ -14,20 +14,18 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-
 package org.apache.arrow.vector;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNull;
-import static org.junit.Assert.assertSame;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertSame;
 import static org.junit.jupiter.api.Assertions.assertThrows;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.List;
-
 import org.apache.arrow.memory.ArrowBuf;
 import org.apache.arrow.memory.BufferAllocator;
 import org.apache.arrow.util.AutoCloseables;
@@ -44,21 +42,20 @@ import org.apache.arrow.vector.types.pojo.ArrowType;
 import org.apache.arrow.vector.types.pojo.Field;
 import org.apache.arrow.vector.types.pojo.FieldType;
 import org.apache.arrow.vector.util.TransferPair;
-import org.junit.After;
-import org.junit.Assert;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 public class TestListVector {
 
   private BufferAllocator allocator;
 
-  @Before
+  @BeforeEach
   public void init() {
     allocator = new DirtyRootAllocator(Long.MAX_VALUE, (byte) 100);
   }
 
-  @After
+  @AfterEach
   public void terminate() throws Exception {
     allocator.close();
   }
@@ -66,7 +63,7 @@ public class TestListVector {
   @Test
   public void testCopyFrom() throws Exception {
     try (ListVector inVector = ListVector.empty("input", allocator);
-         ListVector outVector = ListVector.empty("output", allocator)) {
+        ListVector outVector = ListVector.empty("output", allocator)) {
       UnionListWriter writer = inVector.getWriter();
       writer.allocate();
 
@@ -96,12 +93,11 @@ public class TestListVector {
 
       // assert the output vector is correct
       FieldReader reader = outVector.getReader();
-      Assert.assertTrue("shouldn't be null", reader.isSet());
+      assertTrue(reader.isSet(), "shouldn't be null");
       reader.setPosition(1);
-      Assert.assertFalse("should be null", reader.isSet());
+      assertFalse(reader.isSet(), "should be null");
       reader.setPosition(2);
-      Assert.assertTrue("shouldn't be null", reader.isSet());
-
+      assertTrue(reader.isSet(), "shouldn't be null");
 
       /* index 0 */
       Object result = outVector.getObject(0);
@@ -434,20 +430,26 @@ public class TestListVector {
           BigIntVector dataVector1 = (BigIntVector) toVector.getDataVector();
 
           for (int i = 0; i < splitLength; i++) {
-            dataLength1 = offsetBuffer.getInt((start + i + 1) * ListVector.OFFSET_WIDTH) -
-                    offsetBuffer.getInt((start + i) * ListVector.OFFSET_WIDTH);
-            dataLength2 = toOffsetBuffer.getInt((i + 1) * ListVector.OFFSET_WIDTH) -
-                    toOffsetBuffer.getInt(i * ListVector.OFFSET_WIDTH);
+            dataLength1 =
+                offsetBuffer.getInt((start + i + 1) * ListVector.OFFSET_WIDTH)
+                    - offsetBuffer.getInt((start + i) * ListVector.OFFSET_WIDTH);
+            dataLength2 =
+                toOffsetBuffer.getInt((i + 1) * ListVector.OFFSET_WIDTH)
+                    - toOffsetBuffer.getInt(i * ListVector.OFFSET_WIDTH);
 
-            assertEquals("Different data lengths at index: " + i + " and start: " + start,
-                    dataLength1, dataLength2);
+            assertEquals(
+                dataLength1,
+                dataLength2,
+                "Different data lengths at index: " + i + " and start: " + start);
 
             offset1 = offsetBuffer.getInt((start + i) * ListVector.OFFSET_WIDTH);
             offset2 = toOffsetBuffer.getInt(i * ListVector.OFFSET_WIDTH);
 
             for (int j = 0; j < dataLength1; j++) {
-              assertEquals("Different data at indexes: " + offset1 + " and " + offset2,
-                      dataVector.getObject(offset1), dataVector1.getObject(offset2));
+              assertEquals(
+                  dataVector.getObject(offset1),
+                  dataVector1.getObject(offset2),
+                  "Different data at indexes: " + offset1 + " and " + offset2);
 
               offset1++;
               offset2++;
@@ -840,7 +842,8 @@ public class TestListVector {
   public void testClearAndReuse() {
     try (final ListVector vector = ListVector.empty("list", allocator)) {
       BigIntVector bigIntVector =
-          (BigIntVector) vector.addOrGetVector(FieldType.nullable(MinorType.BIGINT.getType())).getVector();
+          (BigIntVector)
+              vector.addOrGetVector(FieldType.nullable(MinorType.BIGINT.getType())).getVector();
       vector.setInitialCapacity(10);
       vector.allocateNew();
 
@@ -889,17 +892,23 @@ public class TestListVector {
       UnionListWriter writer = vector.getWriter();
       writer.allocate();
 
-      //set some values
+      // set some values
       writer.startList();
       writer.integer().writeInt(1);
       writer.integer().writeInt(2);
       writer.endList();
       vector.setValueCount(2);
 
-      Field expectedDataField = new Field(BaseRepeatedValueVector.DATA_VECTOR_NAME,
-          FieldType.nullable(new ArrowType.Int(32, true)), null);
-      Field expectedField = new Field(vector.getName(), FieldType.nullable(ArrowType.List.INSTANCE),
-          Arrays.asList(expectedDataField));
+      Field expectedDataField =
+          new Field(
+              BaseRepeatedValueVector.DATA_VECTOR_NAME,
+              FieldType.nullable(new ArrowType.Int(32, true)),
+              null);
+      Field expectedField =
+          new Field(
+              vector.getName(),
+              FieldType.nullable(ArrowType.List.INSTANCE),
+              Arrays.asList(expectedDataField));
 
       assertEquals(expectedField, writer.getField());
     }
@@ -917,10 +926,16 @@ public class TestListVector {
       writer.endList();
       vector.setValueCount(1);
 
-      Field expectedDataField = new Field(BaseRepeatedValueVector.DATA_VECTOR_NAME,
-          FieldType.nullable(new ArrowType.Timestamp(TimeUnit.MILLISECOND, "UTC")), null);
-      Field expectedField = new Field(vector.getName(), FieldType.nullable(ArrowType.List.INSTANCE),
-          Arrays.asList(expectedDataField));
+      Field expectedDataField =
+          new Field(
+              BaseRepeatedValueVector.DATA_VECTOR_NAME,
+              FieldType.nullable(new ArrowType.Timestamp(TimeUnit.MILLISECOND, "UTC")),
+              null);
+      Field expectedField =
+          new Field(
+              vector.getName(),
+              FieldType.nullable(ArrowType.List.INSTANCE),
+              Arrays.asList(expectedDataField));
 
       assertEquals(expectedField, writer.getField());
     }
@@ -943,17 +958,26 @@ public class TestListVector {
       // Writing with a different timezone should throw
       holder.timezone = "AsdfTimeZone";
       holder.value = 77777;
-      IllegalArgumentException ex = assertThrows(IllegalArgumentException.class,
-          () -> writer.timeStampMilliTZ().write(holder));
-      assertEquals("holder.timezone: AsdfTimeZone not equal to vector timezone: SomeFakeTimeZone", ex.getMessage());
+      IllegalArgumentException ex =
+          assertThrows(
+              IllegalArgumentException.class, () -> writer.timeStampMilliTZ().write(holder));
+      assertEquals(
+          "holder.timezone: AsdfTimeZone not equal to vector timezone: SomeFakeTimeZone",
+          ex.getMessage());
 
       writer.endList();
       vector.setValueCount(1);
 
-      Field expectedDataField = new Field(BaseRepeatedValueVector.DATA_VECTOR_NAME,
-          FieldType.nullable(new ArrowType.Timestamp(TimeUnit.MILLISECOND, "SomeFakeTimeZone")), null);
-      Field expectedField = new Field(vector.getName(), FieldType.nullable(ArrowType.List.INSTANCE),
-          Arrays.asList(expectedDataField));
+      Field expectedDataField =
+          new Field(
+              BaseRepeatedValueVector.DATA_VECTOR_NAME,
+              FieldType.nullable(new ArrowType.Timestamp(TimeUnit.MILLISECOND, "SomeFakeTimeZone")),
+              null);
+      Field expectedField =
+          new Field(
+              vector.getName(),
+              FieldType.nullable(ArrowType.List.INSTANCE),
+              Arrays.asList(expectedDataField));
 
       assertEquals(expectedField, writer.getField());
     }
@@ -977,17 +1001,24 @@ public class TestListVector {
       // Writing with a different unit should throw
       durationHolder.unit = TimeUnit.SECOND;
       durationHolder.value = 8888888;
-      IllegalArgumentException ex = assertThrows(IllegalArgumentException.class,
-          () -> writer.duration().write(durationHolder));
+      IllegalArgumentException ex =
+          assertThrows(
+              IllegalArgumentException.class, () -> writer.duration().write(durationHolder));
       assertEquals("holder.unit: SECOND not equal to vector unit: MILLISECOND", ex.getMessage());
 
       writer.endList();
       vector.setValueCount(1);
 
-      Field expectedDataField = new Field(BaseRepeatedValueVector.DATA_VECTOR_NAME,
-          FieldType.nullable(new ArrowType.Duration(TimeUnit.MILLISECOND)), null);
-      Field expectedField = new Field(vector.getName(), FieldType.nullable(ArrowType.List.INSTANCE),
-          Arrays.asList(expectedDataField));
+      Field expectedDataField =
+          new Field(
+              BaseRepeatedValueVector.DATA_VECTOR_NAME,
+              FieldType.nullable(new ArrowType.Duration(TimeUnit.MILLISECOND)),
+              null);
+      Field expectedField =
+          new Field(
+              vector.getName(),
+              FieldType.nullable(ArrowType.List.INSTANCE),
+              Arrays.asList(expectedDataField));
 
       assertEquals(expectedField, writer.getField());
     }
@@ -1026,17 +1057,24 @@ public class TestListVector {
       // Writing with a different byteWidth should throw
       // Note just reusing the last buffer value since that won't matter here anyway
       binHolder.byteWidth = 3;
-      IllegalArgumentException ex = assertThrows(IllegalArgumentException.class,
-          () -> writer.fixedSizeBinary().write(binHolder));
+      IllegalArgumentException ex =
+          assertThrows(
+              IllegalArgumentException.class, () -> writer.fixedSizeBinary().write(binHolder));
       assertEquals("holder.byteWidth: 3 not equal to vector byteWidth: 9", ex.getMessage());
 
       writer.endList();
       vector.setValueCount(1);
 
-      Field expectedDataField = new Field(BaseRepeatedValueVector.DATA_VECTOR_NAME,
-          FieldType.nullable(new ArrowType.FixedSizeBinary(byteWidth)), null);
-      Field expectedField = new Field(vector.getName(), FieldType.nullable(ArrowType.List.INSTANCE),
-          Arrays.asList(expectedDataField));
+      Field expectedDataField =
+          new Field(
+              BaseRepeatedValueVector.DATA_VECTOR_NAME,
+              FieldType.nullable(new ArrowType.FixedSizeBinary(byteWidth)),
+              null);
+      Field expectedField =
+          new Field(
+              vector.getName(),
+              FieldType.nullable(ArrowType.List.INSTANCE),
+              Arrays.asList(expectedDataField));
 
       assertEquals(expectedField, writer.getField());
     }
@@ -1050,7 +1088,7 @@ public class TestListVector {
       UnionListWriter writer = vector.getWriter();
       writer.allocate();
 
-      //set some values
+      // set some values
       writer.startList();
       writer.integer().writeInt(1);
       writer.integer().writeInt(2);
@@ -1073,7 +1111,7 @@ public class TestListVector {
       UnionListWriter writer = vector.getWriter();
       writer.allocate();
 
-      //set some values
+      // set some values
       writeIntValues(writer, new int[] {1, 2});
       writeIntValues(writer, new int[] {3, 4});
       writeIntValues(writer, new int[] {5, 6});
@@ -1088,7 +1126,10 @@ public class TestListVector {
         int validityBufferSize = BitVectorHelper.getValidityBufferSize(valueCount);
         int offsetBufferSize = (valueCount + 1) * BaseRepeatedValueVector.OFFSET_WIDTH;
 
-        int expectedSize = validityBufferSize + offsetBufferSize + dataVector.getBufferSizeFor(indices[valueCount]);
+        int expectedSize =
+            validityBufferSize
+                + offsetBufferSize
+                + dataVector.getBufferSizeFor(indices[valueCount]);
         assertEquals(expectedSize, vector.getBufferSizeFor(valueCount));
       }
     }
@@ -1148,17 +1189,18 @@ public class TestListVector {
       writer.bigInt().writeBigInt(3);
       writer.endList();
       writer.setValueCount(1);
-      final TransferPair transferPair = fromVector.getTransferPair(fromVector.getField(),
-          allocator);
+      final TransferPair transferPair =
+          fromVector.getTransferPair(fromVector.getField(), allocator);
       final ListVector toVector = (ListVector) transferPair.getTo();
-      // Field inside a new vector created by reusing a field should be the same in memory as the original field.
+      // Field inside a new vector created by reusing a field should be the same in memory as the
+      // original field.
       assertSame(toVector.getField(), fromVector.getField());
     }
   }
 
   private void writeIntValues(UnionListWriter writer, int[] values) {
     writer.startList();
-    for (int v: values) {
+    for (int v : values) {
       writer.integer().writeInt(v);
     }
     writer.endList();
